Client
======

The main entry point for the SDK. :class:`~etoropy.EToroTrading` wraps REST
endpoints, WebSocket streaming, and instrument resolution behind a single
async interface.

EToroTrading
------------

.. autoclass:: etoropy.EToroTrading
   :members:
   :show-inheritance:

OrderOptions
------------

.. autoclass:: etoropy.OrderOptions
   :members:

InstrumentResolver
------------------

.. autoclass:: etoropy.InstrumentResolver
   :members:
   :show-inheritance:

InstrumentInfo
--------------

.. autoclass:: etoropy.InstrumentInfo
   :members:
